@@ -58,7 +58,7 @@
 #' Zumel N and Mount J (2017) "vtreat: a data.frame Processor for Predictive
 #' Modeling," arXiv:1611.09477
 #'
-#' @examples
+#' @examplesIf rlang::is_installed("modeldata")
 #' library(recipes)
 #' library(dplyr)
 #' library(modeldata)
@@ -161,7 +161,7 @@ glm_coefs <- function(x, y, wts = NULL, ...) {
   mod <-
     glm(
       form,
-      data = bind_cols(x, y),
+      data = vec_cbind(x, y),
       family = fam,
       weights = wts,
       na.action = na.omit,
@@ -222,17 +222,25 @@ print.step_lencode_glm <-
 #' @export
 tidy.step_lencode_glm <- function(x, ...) {
   if (is_trained(x)) {
+    if (length(x$mapping) == 0) {
+      res <- tibble(
+        terms = character(),
+        level = character(),
+        value = double()
+      )
+    } else {
     for (i in seq_along(x$mapping)) {
       x$mapping[[i]]$terms <- names(x$mapping)[i]
     }
     res <- bind_rows(x$mapping)
     names(res) <- gsub("^\\.\\.", "", names(res))
+    }
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(
+      terms = term_names,
       level = rep(na_chr, length(term_names)),
-      value = rep(na_dbl, length(term_names)),
-      terms = term_names
+      value = rep(na_dbl, length(term_names))
     )
   }
   res$id <- x$id
