@@ -85,7 +85,7 @@
 #' Good, I. J. (1985), "Weight of evidence: A brief survey", _Bayesian
 #' Statistics_, 2, pp.249-270.
 #'
-#' @examples
+#' @examplesIf rlang::is_installed("modeldata")
 #' library(modeldata)
 #' data("credit_data")
 #'
@@ -485,9 +485,21 @@ print.step_woe <- function(x, width = max(20, options()$width - 29), ...) {
 #' @export
 tidy.step_woe <- function(x, ...) {
   if (is_trained(x)) {
-    res <-
-      x$dictionary %>%
-      dplyr::rename(terms = variable, value = predictor)
+    if (length(x$terms) == 0) {
+      res <- tibble(
+        terms = character(),
+        value = character(),
+        n_tot = integer(),
+        n_bad = integer(),
+        n_good = integer(),
+        p_bad = double(),
+        p_good = double(),
+        woe = double()
+      )
+    } else {
+      res <- x$dictionary %>%
+        dplyr::rename(terms = variable, value = predictor)
+    }
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(
